# QUANTCONNECT.COM - Democratizing Finance, Empowering Individuals.
# Lean CLI v1.0. Copyright 2021 QuantConnect Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from lean.models.data_providers.terminal_link import TerminalLinkDataProvider
from lean.models.data_providers.local import LocalDataProvider
from lean.models.data_providers.quantconnect import QuantConnectDataProvider

all_data_providers = [
    LocalDataProvider,
    QuantConnectDataProvider,
    TerminalLinkDataProvider
]
